@@ -2,7 +2,7 @@ use 5.012;
 use warnings;
 
 package SQL::Interpol;
-$SQL::Interpol::VERSION = '1.004';
+$SQL::Interpol::VERSION = '1.100';
 # ABSTRACT: interpolate Perl variables into SQL statements
 
 use Exporter::Tidy all => [ qw( sql_interp sql ) ];
@@ -18,7 +18,7 @@ sub sql_interp {
 
 
 package SQL::Interpol::Parser;
-$SQL::Interpol::Parser::VERSION = '1.004';
+$SQL::Interpol::Parser::VERSION = '1.100';
 use Object::Tiny::Lvalue qw( alias_id bind );
 
 use Carp ();
@@ -154,9 +154,10 @@ sub parse {
 # interpolate values from aggregate variable (hashref or arrayref)
 sub bind_or_parse_values {
     my $self = shift;
-    map { ref $_
-        ? $self->parse( $_ )
-        : do { push @{ $self->bind }, $_; '?' }
+    map {
+        my $type = ref;
+        _error "unrecognized $type value in aggregate" if $type and 'HASH' eq $type;
+        $type ? $self->parse( $_ ) : ( '?', push @{ $self->bind }, $_ )[0];
     } @_;
 }
 
@@ -174,7 +175,7 @@ SQL::Interpol - interpolate Perl variables into SQL statements
 
 =head1 VERSION
 
-version 1.004
+version 1.100
 
 =head1 SYNOPSIS
 
